@@ -1,10 +1,11 @@
-from pymatgen.io.vasp.sets import DictSet, _load_yaml_config
+from pymatgen.io.vasp.sets import DictSet, _load_yaml_config, MPRelaxSet
 from pymatgen.core.structure import Structure
-from atomate.vasp.workflows.base.core import get_wf
+#from atomate.vasp.workflows.base.core import get_wf
 from atomate.vasp.fireworks.core import StaticFW, NonSCFFW
 from atomate.vasp.powerups import add_small_gap_multiply, add_stability_check, add_modify_incar, \
     add_wf_metadata, add_common_powerups
 from quantumML.fireworks import OptimizeFW2D
+from atomate.utils.utils import get_wf_from_spec_dict
 
 from atomate.vasp.config import SMALLGAP_KPOINT_MULTIPLY, STABILITY_CHECK, VASP_CMD, DB_FILE, \
     ADD_WF_METADATA, VDW_KERNEL_DIR
@@ -49,20 +50,18 @@ class MPRelaxSet2D(DictSet):
         super().__init__(structure, MPRelaxSet2D.CONFIG, user_incar_settings=incar, **kwargs)
         self.kwargs = kwargs
 
-
-
 def wf_bandstructure2D(structure, c=None):
 
     c = c or {}
     vasp_cmd = c.get("VASP_CMD", VASP_CMD)
     db_file = c.get("DB_FILE", DB_FILE)
     vdw_kernel = c.get("VDW_KERNEL_DIR", VDW_KERNEL_DIR)
-
-    mpr2d = MPRelaxSet2D(structure, force_gamma=True)
+    incar = _read_user_incar('Relax2D.txt')
+    mpr2d = MPRelaxSet(structure, force_gamma=True, user_incar_settings=incar)
     fws = [OptimizeFW2D(structure=structure, vasp_input_set=mpr2d, vasp_cmd=vasp_cmd, db_file=db_file, vdw_kernel_dir=vdw_kernel)]
-    fws.append(StaticFW(parents=0))
-    fws.append(NonSCFFW(parents=1, mode='uniform'))
-    fws.append(NonSCFFW(parents=1, mode='line'))
+    fws.append(StaticFW(parents=fws[0]))
+    fws.append(NonSCFFW(parents=fws[1], mode='uniform'))
+    fws.append(NonSCFFW(parents=fws[1], mode='line'))
     wf = Workflow(fws)
     '''check bandstructure.yaml'''
     '''
